@@ -16,19 +16,18 @@
 
 from typing import Optional
 
-from hspylib.core.crud.crud_service import CrudService
-from hspylib.core.metaclass.singleton import Singleton
+from hspylib.core.datasource.crud_service import CrudService
 
+from vault.core.vault_config import VaultConfig
 from vault.core.vault_repository import VaultRepository
 from vault.entity.vault_entry import VaultEntry
 
 
-class VaultService(CrudService, metaclass=Singleton):
+class VaultService(CrudService[VaultEntry]):
     """Provides a CRUD service for the Vault application"""
 
-    def __init__(self):
-        self.repository = VaultRepository()
-        super().__init__(self.repository)
+    def __init__(self, vault_config: VaultConfig):
+        super().__init__(VaultRepository(vault_config))
 
     def get_by_key(self, key: str) -> Optional[VaultEntry]:
         """Get aa vault entry using the specified key
